@@ -72,7 +72,7 @@ void RichTextComposerEmailQuoteHighlighter::toggleSpellHighlighting(bool on)
 void RichTextComposerEmailQuoteHighlighter::highlightBlock(const QString &text)
 {
     QString simplified = text;
-    simplified.remove(QRegularExpression(QStringLiteral("\\s"))).replace(QLatin1Char('|'), QLatin1Char('>'));
+    simplified.remove(QRegularExpression(u"\\s"_s)).replace(u'|', u'>');
 
     while (simplified.startsWith(">>>>"_L1)) {
         simplified.remove(0, 3);
