@@ -46,73 +46,73 @@ TextHTMLBuilder::~TextHTMLBuilder()
 void TextHTMLBuilder::beginStrong()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<strong>"));
+    d->mText.append(u"<strong>"_s);
 }
 
 void TextHTMLBuilder::endStrong()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</strong>"));
+    d->mText.append(u"</strong>"_s);
 }
 
 void TextHTMLBuilder::beginEmph()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<em>"));
+    d->mText.append(u"<em>"_s);
 }
 
 void TextHTMLBuilder::endEmph()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</em>"));
+    d->mText.append(u"</em>"_s);
 }
 
 void TextHTMLBuilder::beginUnderline()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<u>"));
+    d->mText.append(u"<u>"_s);
 }
 
 void TextHTMLBuilder::endUnderline()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</u>"));
+    d->mText.append(u"</u>"_s);
 }
 
 void TextHTMLBuilder::beginStrikeout()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<s>"));
+    d->mText.append(u"<s>"_s);
 }
 
 void TextHTMLBuilder::endStrikeout()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</s>"));
+    d->mText.append(u"</s>"_s);
 }
 
 void TextHTMLBuilder::beginForeground(const QBrush &brush)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<span style=\"color:%1;\">").arg(brush.color().name()));
+    d->mText.append(u"<span style=\"color:%1;\">"_s.arg(brush.color().name()));
 }
 
 void TextHTMLBuilder::endForeground()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</span>"));
+    d->mText.append(u"</span>"_s);
 }
 
 void TextHTMLBuilder::beginBackground(const QBrush &brush)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<span style=\"background-color:%1;\">").arg(brush.color().name()));
+    d->mText.append(u"<span style=\"background-color:%1;\">"_s.arg(brush.color().name()));
 }
 
 void TextHTMLBuilder::endBackground()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</span>"));
+    d->mText.append(u"</span>"_s);
 }
 
 void TextHTMLBuilder::beginAnchor(const QString &href, const QString &name)
@@ -120,13 +120,13 @@ void TextHTMLBuilder::beginAnchor(const QString &href, const QString &name)
     Q_D(TextHTMLBuilder);
     if (!href.isEmpty()) {
         if (!name.isEmpty()) {
-            d->mText.append(QStringLiteral("<a href=\"%1\" name=\"%2\">").arg(href, name));
+            d->mText.append(u"<a href=\"%1\" name=\"%2\">"_s.arg(href, name));
         } else {
-            d->mText.append(QStringLiteral("<a href=\"%1\">").arg(href));
+            d->mText.append(u"<a href=\"%1\">"_s.arg(href));
         }
     } else {
         if (!name.isEmpty()) {
-            d->mText.append(QStringLiteral("<a name=\"%1\">").arg(name));
+            d->mText.append(u"<a name=\"%1\">"_s.arg(name));
         }
     }
 }
@@ -134,31 +134,31 @@ void TextHTMLBuilder::beginAnchor(const QString &href, const QString &name)
 void TextHTMLBuilder::endAnchor()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</a>"));
+    d->mText.append(u"</a>"_s);
 }
 
 void TextHTMLBuilder::beginFontFamily(const QString &family)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<span style=\"font-family:%1;\">").arg(family));
+    d->mText.append(u"<span style=\"font-family:%1;\">"_s.arg(family));
 }
 
 void TextHTMLBuilder::endFontFamily()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</span>"));
+    d->mText.append(u"</span>"_s);
 }
 
 void TextHTMLBuilder::beginFontPointSize(int size)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<span style=\"font-size:%1pt;\">").arg(QString::number(size)));
+    d->mText.append(u"<span style=\"font-size:%1pt;\">"_s.arg(QString::number(size)));
 }
 
 void TextHTMLBuilder::endFontPointSize()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</span>"));
+    d->mText.append(u"</span>"_s);
 }
 
 void TextHTMLBuilder::beginParagraph(Qt::Alignment al, qreal topMargin, qreal bottomMargin, qreal leftMargin, qreal rightMargin, bool leftToRightText)
@@ -168,34 +168,32 @@ void TextHTMLBuilder::beginParagraph(Qt::Alignment al, qreal topMargin, qreal bo
     //     if (currentListItemStyles.size() != 0)
     //     {
     QString styleString;
-    styleString.append(QStringLiteral("margin-top:%1;").arg(topMargin));
-    styleString.append(QStringLiteral("margin-bottom:%1;").arg(bottomMargin));
-    styleString.append(QStringLiteral("margin-left:%1;").arg(leftMargin));
-    styleString.append(QStringLiteral("margin-right:%1;").arg(rightMargin));
+    styleString.append(u"margin-top:%1;"_s.arg(topMargin));
+    styleString.append(u"margin-bottom:%1;"_s.arg(bottomMargin));
+    styleString.append(u"margin-left:%1;"_s.arg(leftMargin));
+    styleString.append(u"margin-right:%1;"_s.arg(rightMargin));
 
     // Using == doesn't work here.
     // Using bitwise comparison because an alignment can contain a vertical and
     // a
     // horizontal part.
     if (al & Qt::AlignRight) {
-        d->mText.append(QStringLiteral("<p align=\"right\" "));
+        d->mText.append(u"<p align=\"right\" "_s);
     } else if (al & Qt::AlignHCenter) {
-        d->mText.append(QStringLiteral("<p align=\"center\" "));
+        d->mText.append(u"<p align=\"center\" "_s);
     } else if (al & Qt::AlignJustify) {
-        d->mText.append(QStringLiteral("<p align=\"justify\" "));
+        d->mText.append(u"<p align=\"justify\" "_s);
     } else if (al & Qt::AlignLeft) {
-        d->mText.append(QStringLiteral("<p"));
+        d->mText.append(u"<p"_s);
     } else {
-        d->mText.append(QStringLiteral("<p"));
+        d->mText.append(u"<p"_s);
     }
     // Bug in grantlee => style is not defined
-    if (!styleString.isEmpty()) {
-        d->mText.append(QStringLiteral(" style=\"") + styleString + QLatin1Char('"'));
-    }
+    d->mText.append(u" style=\""_s + styleString + u'"');
     if (leftToRightText) {
-        d->mText.append(QStringLiteral(" dir='rtl'"));
+        d->mText.append(u" dir='rtl'"_s);
     }
-    d->mText.append(QLatin1Char('>'));
+    d->mText.append(u'>');
     //     }
 }
 
@@ -204,22 +202,22 @@ void TextHTMLBuilder::beginHeader(int level)
     Q_D(TextHTMLBuilder);
     switch (level) {
     case 1:
-        d->mText.append(QStringLiteral("<h1>"));
+        d->mText.append(u"<h1>"_s);
         break;
     case 2:
-        d->mText.append(QStringLiteral("<h2>"));
+        d->mText.append(u"<h2>"_s);
         break;
     case 3:
-        d->mText.append(QStringLiteral("<h3>"));
+        d->mText.append(u"<h3>"_s);
         break;
     case 4:
-        d->mText.append(QStringLiteral("<h4>"));
+        d->mText.append(u"<h4>"_s);
         break;
     case 5:
-        d->mText.append(QStringLiteral("<h5>"));
+        d->mText.append(u"<h5>"_s);
         break;
     case 6:
-        d->mText.append(QStringLiteral("<h6>"));
+        d->mText.append(u"<h6>"_s);
         break;
     default:
         break;
@@ -231,22 +229,22 @@ void TextHTMLBuilder::endHeader(int level)
     Q_D(TextHTMLBuilder);
     switch (level) {
     case 1:
-        d->mText.append(QStringLiteral("</h1>"));
+        d->mText.append(u"</h1>"_s);
         break;
     case 2:
-        d->mText.append(QStringLiteral("</h2>"));
+        d->mText.append(u"</h2>"_s);
         break;
     case 3:
-        d->mText.append(QStringLiteral("</h3>"));
+        d->mText.append(u"</h3>"_s);
         break;
     case 4:
-        d->mText.append(QStringLiteral("</h4>"));
+        d->mText.append(u"</h4>"_s);
         break;
     case 5:
-        d->mText.append(QStringLiteral("</h5>"));
+        d->mText.append(u"</h5>"_s);
         break;
     case 6:
-        d->mText.append(QStringLiteral("</h6>"));
+        d->mText.append(u"</h6>"_s);
         break;
     default:
         break;
@@ -256,35 +254,35 @@ void TextHTMLBuilder::endHeader(int level)
 void TextHTMLBuilder::endParagraph()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</p>\n"));
+    d->mText.append(u"</p>\n"_s);
 }
 
 void TextHTMLBuilder::addNewline()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<p>&nbsp;"));
+    d->mText.append(u"<p>&nbsp;"_s);
 }
 
 void TextHTMLBuilder::insertHorizontalRule(int width)
 {
     Q_D(TextHTMLBuilder);
     if (width != -1) {
-        d->mText.append(QStringLiteral("<hr width=\"%1\" />\n").arg(width));
+        d->mText.append(u"<hr width=\"%1\" />\n"_s.arg(width));
     }
-    d->mText.append(QStringLiteral("<hr />\n"));
+    d->mText.append(u"<hr />\n"_s);
 }
 
 void TextHTMLBuilder::insertImage(const QString &src, qreal width, qreal height)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<img src=\"%1\" ").arg(src));
+    d->mText.append(u"<img src=\"%1\" "_s.arg(src));
     if (width != 0) {
-        d->mText.append(QStringLiteral("width=\"%2\" ").arg(width));
+        d->mText.append(u"width=\"%2\" "_s.arg(width));
     }
     if (height != 0) {
-        d->mText.append(QStringLiteral("height=\"%2\" ").arg(height));
+        d->mText.append(u"height=\"%2\" "_s.arg(height));
     }
-    d->mText.append(QStringLiteral("/>"));
+    d->mText.append(u"/>"_s);
 }
 
 void TextHTMLBuilder::beginList(QTextListFormat::Style type)
@@ -293,28 +291,28 @@ void TextHTMLBuilder::beginList(QTextListFormat::Style type)
     d->currentListItemStyles.append(type);
     switch (type) {
     case QTextListFormat::ListDisc:
-        d->mText.append(QStringLiteral("<ul type=\"disc\">\n"));
+        d->mText.append(u"<ul type=\"disc\">\n"_s);
         break;
     case QTextListFormat::ListCircle:
-        d->mText.append(QStringLiteral("\n<ul type=\"circle\">\n"));
+        d->mText.append(u"\n<ul type=\"circle\">\n"_s);
         break;
     case QTextListFormat::ListSquare:
-        d->mText.append(QStringLiteral("\n<ul type=\"square\">\n"));
+        d->mText.append(u"\n<ul type=\"square\">\n"_s);
         break;
     case QTextListFormat::ListDecimal:
-        d->mText.append(QStringLiteral("\n<ol type=\"1\">\n"));
+        d->mText.append(u"\n<ol type=\"1\">\n"_s);
         break;
     case QTextListFormat::ListLowerAlpha:
-        d->mText.append(QStringLiteral("\n<ol type=\"a\">\n"));
+        d->mText.append(u"\n<ol type=\"a\">\n"_s);
         break;
     case QTextListFormat::ListUpperAlpha:
-        d->mText.append(QStringLiteral("\n<ol type=\"A\">\n"));
+        d->mText.append(u"\n<ol type=\"A\">\n"_s);
         break;
     case QTextListFormat::ListLowerRoman:
-        d->mText.append(QStringLiteral("\n<ol type=\"i\">\n"));
+        d->mText.append(u"\n<ol type=\"i\">\n"_s);
         break;
     case QTextListFormat::ListUpperRoman:
-        d->mText.append(QStringLiteral("\n<ol type=\"I\">\n"));
+        d->mText.append(u"\n<ol type=\"I\">\n"_s);
         break;
     default:
         break;
@@ -327,14 +325,14 @@ void TextHTMLBuilder::endList()
     case QTextListFormat::ListDisc:
     case QTextListFormat::ListCircle:
     case QTextListFormat::ListSquare:
-        d->mText.append(QStringLiteral("</ul>\n"));
+        d->mText.append(u"</ul>\n"_s);
         break;
     case QTextListFormat::ListDecimal:
     case QTextListFormat::ListLowerAlpha:
     case QTextListFormat::ListUpperAlpha:
     case QTextListFormat::ListLowerRoman:
     case QTextListFormat::ListUpperRoman:
-        d->mText.append(QStringLiteral("</ol>\n"));
+        d->mText.append(u"</ol>\n"_s);
         break;
     default:
         break;
@@ -344,37 +342,37 @@ void TextHTMLBuilder::endList()
 void TextHTMLBuilder::beginListItem()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<li>"));
+    d->mText.append(u"<li>"_s);
 }
 
 void TextHTMLBuilder::endListItem()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</li>\n"));
+    d->mText.append(u"</li>\n"_s);
 }
 
 void TextHTMLBuilder::beginSuperscript()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<sup>"));
+    d->mText.append(u"<sup>"_s);
 }
 
 void TextHTMLBuilder::endSuperscript()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</sup>"));
+    d->mText.append(u"</sup>"_s);
 }
 
 void TextHTMLBuilder::beginSubscript()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<sub>"));
+    d->mText.append(u"<sub>"_s);
 }
 
 void TextHTMLBuilder::endSubscript()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</sub>"));
+    d->mText.append(u"</sub>"_s);
 }
 
 void TextHTMLBuilder::beginTable(qreal cellpadding, qreal cellspacing, const QString &width)
@@ -390,43 +388,43 @@ void TextHTMLBuilder::beginTable(qreal cellpadding, qreal cellspacing, const QSt
 void TextHTMLBuilder::beginTableRow()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<tr>"));
+    d->mText.append(u"<tr>"_s);
 }
 
 void TextHTMLBuilder::beginTableHeaderCell(const QString &width, int colspan, int rowspan)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<th width=\"%1\" colspan=\"%2\" rowspan=\"%3\">").arg(width).arg(colspan).arg(rowspan));
+    d->mText.append(u"<th width=\"%1\" colspan=\"%2\" rowspan=\"%3\">"_s.arg(width).arg(colspan).arg(rowspan));
 }
 
 void TextHTMLBuilder::beginTableCell(const QString &width, int colspan, int rowspan)
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("<td width=\"%1\" colspan=\"%2\" rowspan=\"%3\">").arg(width).arg(colspan).arg(rowspan));
+    d->mText.append(u"<td width=\"%1\" colspan=\"%2\" rowspan=\"%3\">"_s.arg(width).arg(colspan).arg(rowspan));
 }
 
 void TextHTMLBuilder::endTable()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</table>"));
+    d->mText.append(u"</table>"_s);
 }
 
 void TextHTMLBuilder::endTableRow()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</tr>"));
+    d->mText.append(u"</tr>"_s);
 }
 
 void TextHTMLBuilder::endTableHeaderCell()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</th>"));
+    d->mText.append(u"</th>"_s);
 }
 
 void TextHTMLBuilder::endTableCell()
 {
     Q_D(TextHTMLBuilder);
-    d->mText.append(QStringLiteral("</td>"));
+    d->mText.append(u"</td>"_s);
 }
 
 void TextHTMLBuilder::appendLiteralText(const QString &text)
@@ -437,18 +435,18 @@ void TextHTMLBuilder::appendLiteralText(const QString &text)
     for (int i = 0, total = textEscaped.length(); i < total; ++i) {
         const QChar c = textEscaped.at(i);
 
-        if (c == QLatin1Char(' ')) {
+        if (c == u' ') {
             if (i == 0) {
-                textEscapedResult += QStringLiteral("&nbsp;");
+                textEscapedResult += u"&nbsp;"_s;
             } else {
-                if (i + 1 < textEscaped.length() && (textEscaped.at(i + 1) == QLatin1Char(' '))) {
-                    textEscapedResult += QStringLiteral("&nbsp;");
+                if (i + 1 < textEscaped.length() && (textEscaped.at(i + 1) == u' ')) {
+                    textEscapedResult += u"&nbsp;"_s;
                 } else {
                     textEscapedResult += c;
                 }
             }
-        } else if (c == QLatin1Char('\t')) {
-            textEscapedResult += QStringLiteral("&nbsp;&nbsp;&nbsp; ");
+        } else if (c == u'\t') {
+            textEscapedResult += u"&nbsp;&nbsp;&nbsp; "_s;
         } else {
             textEscapedResult += c;
         }
